// functions to be cross-compiled on AVR and on Pong simu live in this file
//
// We set Visual Studio to compiles this in C++ so we can use GCC extensions, 
// like bool type and the variable declaration on use even if Visual Studio would not support this for C.

#ifdef _WINDOWS
#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#include "avr-stuff.h"
#else
// functions in RunAVR are in main on real AVR

#endif


#ifdef LANDSCAPE
// width of display (LED count)
#define WIDTH 12
// height of display (LED count)
#define HEIGHT 10
#else
// width of display (LED count)
#define WIDTH 10
// height of display (LED count)
#define HEIGHT 12
#endif

// a simple loop visualisation demo
void RunAVR_simpleLoop()
{
	byte cnt= 0;
	while (!avrEndRun()) {
		Sleep(10);
		avrSetPixel(cnt % WIDTH, cnt % HEIGHT, cnt < 100 ? cnt < 50 ? 2 : 1 : 0);
		++cnt;
		if (cnt == 200) cnt= 0;
		avrTriggerRepaint();
	}
}

// a simple visualisation demo, left/right knobs fill the playfield
void RunAVR_demo() {
	while (!avrEndRun()) {
		_delay_ms(10);
		byte b= (1023-avrGetLeftADC()) / 16;
		for (byte y= 0; y < HEIGHT; ++y)
			for (byte x= 0; x < WIDTH; ++x)
				avrSetPixel(x, y, 0);
		for (byte y= 0; y < HEIGHT; ++y) {
			if (b==0) break;
			for (byte x= 0; x < WIDTH; ++x) {
				if (b==0) break;
				avrSetPixel(x, y, 2);
				--b;
			}
		}
		b= (1023-avrGetRightADC()) / 16;
		for (byte y= 0; y < HEIGHT; ++y) {
			if (b==0) break;
			for (byte x= 0; x < WIDTH; ++x) {
				if (b==0) break;
				avrSetPixel(WIDTH-1-x, HEIGHT-1-y, 1);
				--b;
			}
		}
		avrTriggerRepaint();
	}
}

// the open source clone pong, from Piotr Platek
void RunAVR_pong() {
	extern int main(void);
	main();
}

// conways game of life adapted from qt sample
extern void RunAVR_Life(void);

// select which demo you want, or implement your own
void RunAVR() {
	RunAVR_simpleLoop();
	//RunAVR_demo();
	//RunAVR_pong();
	//RunAVR_Life();
}